diff --git a/Makefile b/Makefile
index 2f17401b7062f06306b1ad3fb52d9a2af5628527..4dd1692d6b0de8023271a6458fb5835476c355d3 100644
--- a/Makefile
+++ b/Makefile
@@ -59,7 +59,7 @@ website:
 	${MAKE} -C doc website
 
 clean_dirs = $(sourceDirectory)
-clean_extensions = fasl dfsl cfsl fasl fas lib dx32fsl lx64fsl lx32fsl ufasl o bak x86f vbin
+clean_extensions = fasl dfsl cfsl fasl fas lib dx32fsl lx64fsl lx32fsl ufasl o bak x86f vbin amd64f sparcf sparc64f hpf hp64f
 
 clean:
 	@for dir in $(clean_dirs); do \
diff --git a/asdf.asd b/asdf.asd
index 3defd25b467effe06fa3321b02ee9192245efcda..0f945f0e0fa07d9028aac43abd84c1271130942f 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.018.16" ;; to be automatically updated by bin/bump-revision
+  :version "2.018.17" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
diff --git a/asdf.lisp b/asdf.lisp
index 5f1ae58cdafd123c00542b3402bb0f46d16c6976..b03876a97f97986f2fb703534d43fa354ae2da11 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
 ;;; This is ASDF 2.018.16: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -107,7 +107,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.018.16")
+         (asdf-version "2.018.17")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -412,7 +412,7 @@ Note that ASDF ALWAYS raises an error if it fails to create an output file when
                 condition-arguments condition-form
                 condition-format condition-location
                 coerce-name)
-         (ftype (function (&optional t) t) initialize-source-registry)
+         (ftype (function (&optional t) (values)) initialize-source-registry)
          #-(or cormanlisp gcl-pre2.7)
          (ftype (function (t t) t) (setf module-components-by-name)))
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
-;;; This is ASDF 2.018.16: Another System Definition Facility.
+;;; This is ASDF 2.018.17: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: